Struct FastmetricsLayer
pub struct FastmetricsLayer { /* private fields */ }layers-fastmetrics only.Expand description
Add fastmetrics metrics for OpenDAL operations and HTTP fetches.
Fastmetrics Metrics
This layer registers operation metrics and HTTP fetch metrics. Please see the documentation of
the [observe] module for metric details.
Examples
Basic Usage
let mut registry = fastmetrics::registry::Registry::default();
let op = Operator::new(services::Memory::default())?
.layer(FastmetricsLayer::builder().register(&mut registry)?);
// Write data into object test.
op.write("test", "Hello, World!").await?;
// Read data from the object.
let bs = op.read("test").await?;
info!("content: {}", String::from_utf8_lossy(&bs.to_bytes()));
// Get object metadata.
let meta = op.stat("test").await?;
info!("meta: {:?}", meta);
// Export prometheus metrics.
let mut output = String::new();
encode(&mut output, ®istry, TextProfile::PrometheusV0_0_4).unwrap();
println!("{}", output);Global Instance
FastmetricsLayer needs to be registered before instantiation.
If there are multiple operators in an application that need the FastmetricsLayer, we could
instantiate it once and pass it to multiple operators. But we cannot directly call
.layer(FastmetricsLayer::builder().register(&mut registry)?) for different services, because
registering the same metrics multiple times to the same registry will cause register errors.
Therefore, we can provide a global instance for the FastmetricsLayer.
fn global_fastmetrics_layer() -> &'static FastmetricsLayer {
static GLOBAL: OnceLock<FastmetricsLayer> = OnceLock::new();
GLOBAL.get_or_init(|| {
FastmetricsLayer::builder()
.register_global()
.expect("Failed to register with the global registry")
})
}
let op = Operator::new(services::Memory::default())?
.layer(global_fastmetrics_layer().clone());
// Write data into object test.
op.write("test", "Hello, World!").await?;
// Read data from the object.
let bs = op.read("test").await?;
info!("content: {}", String::from_utf8_lossy(&bs.to_bytes()));
// Get object metadata.
let meta = op.stat("test").await?;
info!("meta: {:?}", meta);
// Export prometheus metrics.
let mut output = String::new();
with_global_registry(|reg| encode(&mut output, ®, TextProfile::PrometheusV0_0_4).unwrap());
println!("{}", output);Implementations
impl FastmetricsLayer
impl FastmetricsLayer
pub fn builder() -> FastmetricsLayerBuilder
pub fn builder() -> FastmetricsLayerBuilder
Create a FastmetricsLayerBuilder to set the configuration of metrics.