Struct FastraceLayer
#[non_exhaustive]pub struct FastraceLayer {}Available on crate feature
layers-fastrace only.Expand description
Add fastrace for every operation.
The layer creates spans for service calls and for deferred operation bodies such as readers, writers, listers, deleters, and copiers.
Examples
Basic Setup
let _ = Operator::new(services::Memory::default())?
.layer(FastraceLayer::new());Real usage
let reporter = fastrace_jaeger::JaegerReporter::new("127.0.0.1:6831".parse()?, "opendal").unwrap();
fastrace::set_reporter(reporter, fastrace::collector::Config::default());
{
let root = Span::root("op", SpanContext::random());
let runtime = tokio::runtime::Runtime::new()?;
runtime.block_on(
async {
let _ = dotenvy::dotenv();
let op = Operator::new(services::Memory::default())?
.layer(FastraceLayer::new());
op.write("test", "0".repeat(16 * 1024 * 1024).into_bytes())
.await?;
op.stat("test").await?;
op.read("test").await?;
Ok::<(), opendal_core::Error>(())
}
.in_span(Span::enter_with_parent("test", &root)),
)?;
}
fastrace::flush();Output
OpenDAL is using fastrace for tracing internally.
To enable fastrace output, initialize a reporter supported by fastrace.
For example:
let reporter = fastrace_jaeger::JaegerReporter::new("127.0.0.1:6831".parse()?, "opendal").unwrap();
fastrace::set_reporter(reporter, fastrace::collector::Config::default());For real-world usage, take a look at fastrace-datadog or fastrace-jaeger.
Implementations
impl FastraceLayer
impl FastraceLayer
pub fn new() -> FastraceLayer
pub fn new() -> FastraceLayer
Create a new FastraceLayer.