Module services

Module services 

Service builders enabled through services-* Cargo features.

Memory is always available. Other builders are re-exported when their matching facade feature is enabled; for example, services-s3 enables S3.

Pass a configured builder to Operator::new. The facade automatically registers enabled services for Operator::from_uri and Operator::via_iter when the auto-register-services feature is enabled.

Structs

AliyunDriveservices-aliyun-drive
Capabilities
AliyunDriveConfigservices-aliyun-drive
Config for Aliyun Drive services support.
Alluxioservices-alluxio
Alluxio services support.
AlluxioConfigservices-alluxio
Config for alluxio services support.
Azblobservices-azblob
Capabilities
AzblobConfigservices-azblob
Azure Storage Blob services support.
Azdlsservices-azdls
Azure Data Lake Storage Gen2 Support. As known as abfs, azdls or azdls.
AzdlsConfigservices-azdls
Azure Data Lake Storage Gen2 Support.
Azfileservices-azfile
Azure File services support.
AzfileConfigservices-azfile
Azure File services support.
B2services-b2
b2 services support.
B2Configservices-b2
Config for backblaze b2 services support.
Cacacheservices-cacache
cacache service support.
CacacheConfigservices-cacache
cacache service support.
CloudflareKvservices-cloudflare-kv
Capabilities
CloudflareKvConfigservices-cloudflare-kv
Cloudflare KV Service Support.
Compfsservices-compfs
compio-based file system support.
CompfsConfigservices-compfs
compio-based file system support.
Cosservices-cos
Tencent-Cloud COS services support.
CosConfigservices-cos
Tencent-Cloud COS services support.
D1services-d1
Capabilities
D1Configservices-d1
Config for Cloudflare D1 backend support.
Dashmapservices-dashmap
dashmap backend support.
DashmapConfigservices-dashmap
Config for Dashmap services support.
Dbfsservices-dbfs
Dbfs’s REST API support. This service will visit the DBFS API supported by Databricks File System.
DbfsConfigservices-dbfs
Dbfs’s REST API support.
Dropboxservices-dropbox
Dropbox backend support.
DropboxConfigservices-dropbox
Config for Dropbox backend support.
Etcdservices-etcd
Etcd services support.
EtcdConfigservices-etcd
Config for Etcd services support.
Foundationdbservices-foundationdb
Capabilities
FoundationdbConfigservices-foundationdb
foundationdb service support. Config for FoundationDB.
Foyerservices-foyer
foyer backend support.
FoyerConfigservices-foyer
Config for Foyer services support.
FoyerKeyservices-foyer
FoyerKey is a key for the foyer cache.
FoyerValueservices-foyer
FoyerValue is a wrapper around Buffer that implements the Code trait.
Fsservices-fs
POSIX file system support.
FsConfigservices-fs
config for file system
Ftpservices-ftp
FTP and FTPS services support.
FtpConfigservices-ftp
Config for Ftp services support.
Gcsservices-gcs
Google Cloud Storage services support.
GcsConfigservices-gcs
Google Cloud Storage services support.
Gdriveservices-gdrive
GoogleDrive backend support.
GdriveConfigservices-gdrive
GoogleDrive configuration.
Ghacservices-ghac
GitHub Action Cache Services support.
GhacConfigservices-ghac
Config for GitHub Action Cache Services support.
Githubservices-github
github contents services support.
GithubConfigservices-github
Config for GitHub services support.
GooseFsservices-goosefs
GooseFS services support via native gRPC.
GoosefsConfigservices-goosefs
Config for GooseFS service support.
Gridfsservices-gridfs
Capabilities
GridfsConfigservices-gridfs
Config for Grid file system support.
Hdfsservices-hdfs
A distributed file system that provides high-throughput access to application data.
HdfsConfigservices-hdfs
Hadoop Distributed File System (HDFS™) support.
HdfsNativeservices-hdfs-native
Hadoop Distributed File System (HDFS™) support. Using Native Rust HDFS client. A distributed file system that provides high-throughput access to application data. Using Native Rust HDFS client.
HdfsNativeConfigservices-hdfs-native
Config for HdfsNative services support.
Hfservices-hf
Hugging Face’s API support. This service will visit the Hugging Face API to access the Hugging Face File System.
HfConfigservices-hf
Configuration for Hugging Face service support.
Httpservices-http
HTTP Read-only service support like Nginx and Caddy.
HttpConfigservices-http
Config for Http service support.
Ipfsservices-ipfs
IPFS file system support based on IPFS HTTP Gateway.
IpfsConfigservices-ipfs
Config for IPFS file system support.
Ipmfsservices-ipmfs
IPFS file system support based on IPFS MFS API.
IpmfsConfigservices-ipmfs
Config for IPFS MFS support.
Koofrservices-koofr
Koofr services support.
KoofrConfigservices-koofr
Config for Koofr services support.
Lakefsservices-lakefs
Lakefs’s API support. This service will visit the Lakefs API to access the Lakefs File System. Currently, we only support the model and dataset types of repositories, and operations are limited to reading and listing/stating.
LakefsConfigservices-lakefs
Configuration for Lakefs service support.
Memcachedservices-memcached
Memcached service support.
MemcachedConfigservices-memcached
Config for MemCached services support
Memory
In memory service support. (BTreeMap Based)
MemoryConfig
Config for memory.
MiniMokaservices-mini-moka
mini-moka backend support.
MiniMokaConfigservices-mini-moka
Config for mini-moka support.
Mokaservices-moka
moka backend support.
MokaConfigservices-moka
Config for Moka services support.
MokaValueservices-moka
Value stored in moka cache containing both metadata and content
Mongodbservices-mongodb
Capabilities
MongodbConfigservices-mongodb
Config for Mongodb service support.
Monoiofsservices-monoiofs
File system support via monoio.
MonoiofsConfigservices-monoiofs
Config for monoiofs services support.
Mysqlservices-mysql
Capabilities
MysqlConfigservices-mysql
Config for Mysql services support.
Obsservices-obs
Huawei-Cloud Object Storage Service (OBS) support
ObsConfigservices-obs
Config for Huawei-Cloud Object Storage Service (OBS) support.
Onedriveservices-onedrive
Microsoft OneDrive backend support.
OnedriveConfigservices-onedrive
Config for OneDrive backend support.
Ossservices-oss
Aliyun Object Storage Service (OSS) support
OssConfigservices-oss
Config for Aliyun Object Storage Service (OSS) support.
Pcloudservices-pcloud
pCloud services support.
PcloudConfigservices-pcloud
Config for Pcloud services support.
Persyservices-persy
persy service support.
PersyConfigservices-persy
Config for persy service support.
Postgresqlservices-postgresql
PostgreSQL services support.
PostgresqlConfigservices-postgresql
Config for PostgreSQL services support.
Redbservices-redb
Redb service support.
RedbConfigservices-redb
Config for redb service support.
Redisservices-redis
Redis services support.
RedisConfigservices-redis
Config for Redis services support.
Rocksdbservices-rocksdb
RocksDB service support.
RocksdbConfigservices-rocksdb
Config for Rocksdb Service.
S3services-s3
Aws S3 and compatible services (including minio, digitalocean space, Tencent Cloud Object Storage(COS) and so on) support. For more information about s3-compatible services, refer to Compatible Services.
S3Configservices-s3
Config for Aws S3 and compatible services (including minio, digitalocean space, Tencent Cloud Object Storage(COS) and so on) support.
Seafileservices-seafile
seafile services support.
SeafileConfigservices-seafile
Config for seafile services support.
Sftpservices-sftp
SFTP services support. (only works on unix)
SftpConfigservices-sftp
Config for Sftp Service support.
Sledservices-sled
Sled services support.
SledConfigservices-sled
Config for Sled services support.
Sqliteservices-sqlite
Capabilities
SqliteConfigservices-sqlite
Config for Sqlite support.
Surrealdbservices-surrealdb
Capabilities
SurrealdbConfigservices-surrealdb
Config for Surrealdb services support.
Swiftservices-swift
OpenStack Swift’s REST API support. For more information about swift-compatible services, refer to Compatible Services.
SwiftConfigservices-swift
Config for OpenStack Swift support.
Tikvservices-tikv
TiKV backend builder
TikvConfigservices-tikv
Config for Tikv services support.
Tosservices-tos
Builder for Volcengine TOS service.
TosConfigservices-tos
Config for Volcengine TOS service.
Upyunservices-upyun
upyun services support.
UpyunConfigservices-upyun
Config for upyun services support.
VercelArtifactsservices-vercel-artifacts
Vercel Cache backend support.
VercelArtifactsConfigservices-vercel-artifacts
Config for Vercel Cache support.
VercelBlobservices-vercel-blob
VercelBlob services support.
VercelBlobConfigservices-vercel-blob
Config for VercelBlob services support.
Webdavservices-webdav
WebDAV backend support.
WebdavConfigservices-webdav
Config for WebDAV backend support.
Webhdfsservices-webhdfs
WebHDFS’s REST API support. There two implementations of WebHDFS REST API:
WebhdfsConfigservices-webhdfs
Config for WebHDFS support.
YandexDiskservices-yandex-disk
YandexDisk services support.
YandexDiskConfigservices-yandex-disk
Config for YandexDisk services support.

Constants

ALIYUN_DRIVE_SCHEMEservices-aliyun-drive
URI scheme used for service registration and scheme-driven construction.
ALLUXIO_SCHEMEservices-alluxio
URI scheme used for service registration and scheme-driven construction.
AZBLOB_SCHEMEservices-azblob
URI scheme used for service registration and scheme-driven construction.
AZDLS_SCHEMEservices-azdls
URI scheme used for service registration and scheme-driven construction.
AZFILE_SCHEMEservices-azfile
URI scheme used for service registration and scheme-driven construction.
B2_SCHEMEservices-b2
URI scheme used for service registration and scheme-driven construction.
CACACHE_SCHEMEservices-cacache
URI scheme used for service registration and scheme-driven construction.
CLOUDFLARE_KV_SCHEMEservices-cloudflare-kv
URI scheme used for service registration and scheme-driven construction.
COMPFS_SCHEMEservices-compfs
URI scheme used for service registration and scheme-driven construction.
COSN_SCHEMEservices-cos
Alternative scheme for cos service.
COS_SCHEMEservices-cos
URI scheme used for service registration and scheme-driven construction.
D1_SCHEMEservices-d1
URI scheme used for service registration and scheme-driven construction.
DASHMAP_SCHEMEservices-dashmap
URI scheme used for service registration and scheme-driven construction.
DBFS_SCHEMEservices-dbfs
URI scheme used for service registration and scheme-driven construction.
DROPBOX_SCHEMEservices-dropbox
URI scheme used for service registration and scheme-driven construction.
ETCD_SCHEMEservices-etcd
URI scheme used for service registration and scheme-driven construction.
FILE_SCHEMEservices-fs
Alias scheme for fs service that follows the standard URI scheme.
FOUNDATIONDB_SCHEMEservices-foundationdb
URI scheme used for service registration and scheme-driven construction.
FOYER_SCHEMEservices-foyer
URI scheme used for service registration and scheme-driven construction.
FS_SCHEMEservices-fs
URI scheme used for service registration and scheme-driven construction.
FTP_SCHEMEservices-ftp
URI scheme used for service registration and scheme-driven construction.
GCS_SCHEMEservices-gcs
URI scheme used for service registration and scheme-driven construction.
GDRIVE_SCHEMEservices-gdrive
URI scheme used for service registration and scheme-driven construction.
GHAC_SCHEMEservices-ghac
URI scheme used for service registration and scheme-driven construction.
GITHUB_SCHEMEservices-github
URI scheme used for service registration and scheme-driven construction.
GOOSEFS_SCHEMEservices-goosefs
URI scheme used for service registration and scheme-driven construction.
GRIDFS_SCHEMEservices-gridfs
URI scheme used for service registration and scheme-driven construction.
HDFS_NATIVE_SCHEMEservices-hdfs-native
URI scheme used for service registration and scheme-driven construction.
HDFS_SCHEMEservices-hdfs
URI scheme used for service registration and scheme-driven construction.
HF_SCHEMEservices-hf
Primary URI scheme registered for the Hugging Face service.
HTTPS_SCHEMEservices-http
Alias URI scheme used for HTTPS connections.
HTTP_SCHEMEservices-http
URI scheme used for service registration and scheme-driven construction.
HUGGINGFACE_SCHEMEservices-hf
Alias URI scheme registered for the Hugging Face service.
IPFS_SCHEMEservices-ipfs
URI scheme used for service registration and scheme-driven construction.
IPMFS_SCHEMEservices-ipmfs
URI scheme used for service registration and scheme-driven construction.
KOOFR_SCHEMEservices-koofr
URI scheme used for service registration and scheme-driven construction.
LAKEFS_SCHEMEservices-lakefs
URI scheme used for service registration and scheme-driven construction.
MEMCACHED_SCHEMEservices-memcached
URI scheme used for service registration and scheme-driven construction.
MEMORY_SCHEME
URI scheme used for memory service registration and URI construction.
MINI_MOKA_SCHEMEservices-mini-moka
URI scheme used for service registration and scheme-driven construction.
MOKA_SCHEMEservices-moka
URI scheme used for service registration and scheme-driven construction.
MONGODB_SCHEMEservices-mongodb
URI scheme used for service registration and scheme-driven construction.
MONOIOFS_SCHEMEservices-monoiofs
URI scheme used for service registration and scheme-driven construction.
MYSQL_SCHEMEservices-mysql
URI scheme used for service registration and scheme-driven construction.
OBS_SCHEMEservices-obs
URI scheme used for service registration and scheme-driven construction.
ONEDRIVE_SCHEMEservices-onedrive
URI scheme used for service registration and scheme-driven construction.
OSS_SCHEMEservices-oss
URI scheme used for service registration and scheme-driven construction.
PCLOUD_SCHEMEservices-pcloud
URI scheme used for service registration and scheme-driven construction.
PERSY_SCHEMEservices-persy
URI scheme used for service registration and scheme-driven construction.
POSTGRESQL_SCHEMEservices-postgresql
URI scheme used for service registration and scheme-driven construction.
REDB_SCHEMEservices-redb
URI scheme used for service registration and scheme-driven construction.
REDIS_SCHEMEservices-redis
URI scheme used for service registration and scheme-driven construction.
ROCKSDB_SCHEMEservices-rocksdb
URI scheme used for service registration and scheme-driven construction.
S3_SCHEMEservices-s3
URI scheme used for service registration and scheme-driven construction.
SEAFILE_SCHEMEservices-seafile
URI scheme used for service registration and scheme-driven construction.
SFTP_SCHEMEservices-sftp
URI scheme used for service registration and scheme-driven construction.
SLED_SCHEMEservices-sled
URI scheme used for service registration and scheme-driven construction.
SQLITE_SCHEMEservices-sqlite
URI scheme used for service registration and scheme-driven construction.
SURREALDB_SCHEMEservices-surrealdb
URI scheme used for service registration and scheme-driven construction.
SWIFT_SCHEMEservices-swift
URI scheme used for service registration and scheme-driven construction.
TIKV_SCHEMEservices-tikv
URI scheme used for service registration and scheme-driven construction.
TOS_SCHEMEservices-tos
URI scheme used for service registration and scheme-driven construction.
UPYUN_SCHEMEservices-upyun
URI scheme used for service registration and scheme-driven construction.
VERCEL_ARTIFACTS_SCHEMEservices-vercel-artifacts
URI scheme used for service registration and scheme-driven construction.
VERCEL_BLOB_SCHEMEservices-vercel-blob
URI scheme used for service registration and scheme-driven construction.
WEBDAV_SCHEMEservices-webdav
URI scheme used for service registration and scheme-driven construction.
WEBHDFS_SCHEMEservices-webhdfs
URI scheme used for service registration and scheme-driven construction.
YANDEX_DISK_SCHEMEservices-yandex-disk
URI scheme used for service registration and scheme-driven construction.

Functions

register_aliyun_drive_serviceservices-aliyun-drive
Register this service’s URI scheme or schemes with an operator registry.
register_alluxio_serviceservices-alluxio
Register this service’s URI scheme or schemes with an operator registry.
register_azblob_serviceservices-azblob
Register this service’s URI scheme or schemes with an operator registry.
register_azdls_serviceservices-azdls
Register this service’s URI scheme or schemes with an operator registry.
register_azfile_serviceservices-azfile
Register this service’s URI scheme or schemes with an operator registry.
register_b2_serviceservices-b2
Register this service’s URI scheme or schemes with an operator registry.
register_cacache_serviceservices-cacache
Register this service’s URI scheme or schemes with an operator registry.
register_cloudflare_kv_serviceservices-cloudflare-kv
Register this service’s URI scheme or schemes with an operator registry.
register_compfs_serviceservices-compfs
Register this service’s URI scheme or schemes with an operator registry.
register_cos_serviceservices-cos
Register this service’s URI scheme or schemes with an operator registry.
register_d1_serviceservices-d1
Register this service’s URI scheme or schemes with an operator registry.
register_dashmap_serviceservices-dashmap
Register this service’s URI scheme or schemes with an operator registry.
register_dbfs_serviceservices-dbfs
Register this service’s URI scheme or schemes with an operator registry.
register_dropbox_serviceservices-dropbox
Register this service’s URI scheme or schemes with an operator registry.
register_etcd_serviceservices-etcd
Register this service’s URI scheme or schemes with an operator registry.
register_foundationdb_serviceservices-foundationdb
Register this service’s URI scheme or schemes with an operator registry.
register_foyer_serviceservices-foyer
Register this service’s URI scheme or schemes with an operator registry.
register_fs_serviceservices-fs
Register this service’s URI scheme or schemes with an operator registry.
register_ftp_serviceservices-ftp
Register this service’s URI scheme or schemes with an operator registry.
register_gcs_serviceservices-gcs
Register this service’s URI scheme or schemes with an operator registry.
register_gdrive_serviceservices-gdrive
Register this service’s URI scheme or schemes with an operator registry.
register_ghac_serviceservices-ghac
Register this service’s URI scheme or schemes with an operator registry.
register_github_serviceservices-github
Register this service’s URI scheme or schemes with an operator registry.
register_goosefs_serviceservices-goosefs
Register this service’s URI scheme or schemes with an operator registry.
register_gridfs_serviceservices-gridfs
Register this service’s URI scheme or schemes with an operator registry.
register_hdfs_native_serviceservices-hdfs-native
Register this service’s URI scheme or schemes with an operator registry.
register_hdfs_serviceservices-hdfs
Register this service’s URI scheme or schemes with an operator registry.
register_hf_serviceservices-hf
Register this service’s URI scheme or schemes with an operator registry.
register_http_serviceservices-http
Register this service’s URI scheme or schemes with an operator registry.
register_ipfs_serviceservices-ipfs
Register this service’s URI scheme or schemes with an operator registry.
register_ipmfs_serviceservices-ipmfs
Register this service’s URI scheme or schemes with an operator registry.
register_koofr_serviceservices-koofr
Register this service’s URI scheme or schemes with an operator registry.
register_lakefs_serviceservices-lakefs
Register this service’s URI scheme or schemes with an operator registry.
register_memcached_serviceservices-memcached
Register this service’s URI scheme or schemes with an operator registry.
register_memory_service
Register the memory URI scheme with an operator registry.
register_mini_moka_serviceservices-mini-moka
Register this service’s URI scheme or schemes with an operator registry.
register_moka_serviceservices-moka
Register this service’s URI scheme or schemes with an operator registry.
register_mongodb_serviceservices-mongodb
Register this service’s URI scheme or schemes with an operator registry.
register_monoiofs_serviceservices-monoiofs
Register this service’s URI scheme or schemes with an operator registry.
register_mysql_serviceservices-mysql
Register this service’s URI scheme or schemes with an operator registry.
register_obs_serviceservices-obs
Register this service’s URI scheme or schemes with an operator registry.
register_onedrive_serviceservices-onedrive
Register this service’s URI scheme or schemes with an operator registry.
register_oss_serviceservices-oss
Register this service’s URI scheme or schemes with an operator registry.
register_pcloud_serviceservices-pcloud
Register this service’s URI scheme or schemes with an operator registry.
register_persy_serviceservices-persy
Register this service’s URI scheme or schemes with an operator registry.
register_postgresql_serviceservices-postgresql
Register this service’s URI scheme or schemes with an operator registry.
register_redb_serviceservices-redb
Register this service’s URI scheme or schemes with an operator registry.
register_redis_serviceservices-redis
Register this service’s URI scheme or schemes with an operator registry.
register_rocksdb_serviceservices-rocksdb
Register this service’s URI scheme or schemes with an operator registry.
register_s3_serviceservices-s3
Register this service’s URI scheme or schemes with an operator registry.
register_seafile_serviceservices-seafile
Register this service’s URI scheme or schemes with an operator registry.
register_sftp_serviceservices-sftp
Register this service’s URI scheme or schemes with an operator registry.
register_sled_serviceservices-sled
Register this service’s URI scheme or schemes with an operator registry.
register_sqlite_serviceservices-sqlite
Register this service’s URI scheme or schemes with an operator registry.
register_surrealdb_serviceservices-surrealdb
Register this service’s URI scheme or schemes with an operator registry.
register_swift_serviceservices-swift
Register this service’s URI scheme or schemes with an operator registry.
register_tikv_serviceservices-tikv
Register this service’s URI scheme or schemes with an operator registry.
register_tos_serviceservices-tos
Register this service’s URI scheme or schemes with an operator registry.
register_upyun_serviceservices-upyun
Register this service’s URI scheme or schemes with an operator registry.
register_vercel_artifacts_serviceservices-vercel-artifacts
Register this service’s URI scheme or schemes with an operator registry.
register_vercel_blob_serviceservices-vercel-blob
Register this service’s URI scheme or schemes with an operator registry.
register_webdav_serviceservices-webdav
Register this service’s URI scheme or schemes with an operator registry.
register_webhdfs_serviceservices-webhdfs
Register this service’s URI scheme or schemes with an operator registry.
register_yandex_disk_serviceservices-yandex-disk
Register this service’s URI scheme or schemes with an operator registry.

Type Aliases

MokaCacheBuilderservices-moka
Type alias of moka::future::CacheBuilder