Azblob

Struct Azblob 

pub struct Azblob { /* private fields */ }
Available on crate feature services-azblob only.
Capabilities

This service can be used to:

  • create_dir
  • stat
  • read
  • write
  • delete
  • list
  • copy
  • rename
  • presign

Configuration

  • root: Set the work dir for backend.
  • container: Set the container name for backend.
  • endpoint: Set the endpoint for backend.
  • account_name: Set the account_name for backend.
  • account_key: Set the account_key for backend.
  • batch_max_operations: Deprecated. Azblob delete batch capability is enabled by default with Azure Blob’s 256-operation batch limit and this option is no longer needed.

Refer to public API docs for more information.

Examples

This example works on Azurite for local developments.

Start local blob service

docker run -p 10000:10000 mcr.microsoft.com/azure-storage/azurite
az storage container create --name test --connection-string "DefaultEndpointsProtocol=http;AccountName=devstoreaccount1;AccountKey=Eby8vdM02xNOcqFlqUwJPLlmEtlCDXJ1OUzFT50uSRZ6IFsuFq2UVErCz4I6tq/K1SZFPTOtr/KBHBeksoGMGw==;BlobEndpoint=http://127.0.0.1:10000/devstoreaccount1;"

Init OpenDAL Operator

Via Builder

use opendal_core::Operator;
use opendal_core::Result;
use opendal_service_azblob::Azblob;

#[tokio::main]
async fn main() -> Result<()> {
    // Create azblob backend builder.
    let mut builder = Azblob::default()
        // Set the root for azblob, all operations will happen under this root.
        //
        // NOTE: the root must be absolute path.
        .root("/path/to/dir")
        // Set the container name, this is required.
        .container("test")
        // Set the endpoint, this is required.
        //
        // For examples:
        // - "http://127.0.0.1:10000/devstoreaccount1"
        // - "https://accountname.blob.core.windows.net"
        .endpoint("http://127.0.0.1:10000/devstoreaccount1")
        // Set the account_name and account_key.
        //
        // OpenDAL will try load credential from the env.
        // If credential not set and no valid credential in env, OpenDAL will
        // send request without signing like anonymous user.
        .account_name("devstoreaccount1")
        .account_key("Eby8vdM02xNOcqFlqUwJPLlmEtlCDXJ1OUzFT50uSRZ6IFsuFq2UVErCz4I6tq/K1SZFPTOtr/KBHBeksoGMGw==");

    // `Accessor` provides the low level APIs, we will use `Operator` normally.
    let op: Operator = Operator::new(builder)?.finish();
    Ok(())
}

Implementations



impl AzblobBuilder

pub fn root(self, root: &str) -> AzblobBuilder

Set root of this backend.

All operations will happen under this root.

pub fn container(self, container: &str) -> AzblobBuilder

Set container name of this backend.

pub fn endpoint(self, endpoint: &str) -> AzblobBuilder

Set endpoint of this backend

Endpoint must be full uri, e.g.

  • Azblob: https://accountname.blob.core.windows.net
  • Azurite: http://127.0.0.1:10000/devstoreaccount1

pub fn account_name(self, account_name: &str) -> AzblobBuilder

Set account_name of this backend.

  • If account_name is set, we will take user’s input first.
  • If not, we will try to load it from environment.

pub fn account_key(self, account_key: &str) -> AzblobBuilder

Set account_key of this backend.

  • If account_key is set, we will take user’s input first.
  • If not, we will try to load it from environment.

pub fn encryption_key(self, v: &str) -> AzblobBuilder

Set encryption_key of this backend.

Args

v: Base64-encoded key that matches algorithm specified in encryption_algorithm.

Note

This function is the low-level setting for SSE related features.

SSE related options should be set carefully to make them works. Please use server_side_encryption_with_* helpers if even possible.

pub fn encryption_key_sha256(self, v: &str) -> AzblobBuilder

Set encryption_key_sha256 of this backend.

Args

v: Base64-encoded SHA256 digest of the key specified in encryption_key.

Note

This function is the low-level setting for SSE related features.

SSE related options should be set carefully to make them works. Please use server_side_encryption_with_* helpers if even possible.

pub fn encryption_algorithm(self, v: &str) -> AzblobBuilder

Set encryption_algorithm of this backend.

Args

v: server-side encryption algorithm. (Available values: AES256)

Note

This function is the low-level setting for SSE related features.

SSE related options should be set carefully to make them works. Please use server_side_encryption_with_* helpers if even possible.

pub fn server_side_encryption_with_customer_key( self, key: &[u8], ) -> AzblobBuilder

Enable server side encryption with customer key.

As known as: CPK

Args

key: Base64-encoded SHA256 digest of the key specified in encryption_key.

Note

Function that helps the user to set the server-side customer-provided encryption key, the key’s SHA256, and the algorithm. See Server-side encryption with customer-provided keys (CPK) for more info.

pub fn sas_token(self, sas_token: &str) -> AzblobBuilder

Set sas_token of this backend.

  • If sas_token is set, we will take user’s input first.
  • If not, we will try to load it from environment.

See Grant limited access to Azure Storage resources using shared access signatures (SAS) for more info.

pub fn batch_max_operations(self, _batch_max_operations: usize) -> AzblobBuilder

👎Deprecated since 0.57.0: Azblob delete batch capability is enabled by default with Azure Blob’s 256-operation batch limit and this option is no longer needed.

Deprecated: Azblob delete batch capability is enabled by default with Azure Blob’s 256-operation batch limit.

pub fn skip_signature(self) -> AzblobBuilder

Skip signature will skip loading credentials and signing requests.

pub fn from_connection_string(conn: &str) -> Result<AzblobBuilder, Error>

from_connection_string will make a builder from connection string

connection string looks like:

DefaultEndpointsProtocol=http;AccountName=devstoreaccount1;
AccountKey=Eby8vdM02xNOcqFlqUwJPLlmEtlCDXJ1OUzFT50uSRZ6IFsuFq2UVErCz4I6tq/K1SZFPTOtr/KBHBeksoGMGw==;
BlobEndpoint=http://127.0.0.1:10000/devstoreaccount1;
QueueEndpoint=http://127.0.0.1:10001/devstoreaccount1;
TableEndpoint=http://127.0.0.1:10002/devstoreaccount1;

Or

DefaultEndpointsProtocol=https;
AccountName=storagesample;
AccountKey=<account-key>;
EndpointSuffix=core.chinacloudapi.cn;

For reference: Configure Azure Storage connection strings

Note

Connection strings can only configure the endpoint, account name and authentication information. Users still need to configure container name.