Struct AzblobConfig
pub struct AzblobConfig {
pub root: Option<String>,
pub container: String,
pub endpoint: Option<String>,
pub account_name: Option<String>,
pub account_key: Option<String>,
pub encryption_key: Option<String>,
pub encryption_key_sha256: Option<String>,
pub encryption_algorithm: Option<String>,
pub sas_token: Option<String>,
pub batch_max_operations: Option<usize>,
pub skip_signature: bool,
}services-azblob only.Expand description
Azure Storage Blob services support.
Fields
root: Option<String>The root of Azblob service backend.
All operations will happen under this root.
container: StringThe container name of Azblob service backend.
endpoint: Option<String>The endpoint of Azblob service backend.
Endpoint must be full uri, e.g.
- Azblob:
https://accountname.blob.core.windows.net - Azurite:
http://127.0.0.1:10000/devstoreaccount1
account_name: Option<String>The account name of Azblob service backend.
account_key: Option<String>The account key of Azblob service backend.
encryption_key: Option<String>The encryption key of Azblob service backend.
encryption_key_sha256: Option<String>The encryption key sha256 of Azblob service backend.
encryption_algorithm: Option<String>The encryption algorithm of Azblob service backend.
sas_token: Option<String>The sas token of Azblob service backend.
batch_max_operations: Option<usize>Azblob delete batch capability is enabled by default with Azure Blob’s 256-operation batch limit. Use CapabilityOverrideLayer to override delete_max_size for specific endpoints.
Deprecated: Azblob delete batch capability is enabled by default with Azure Blob’s 256-operation batch limit.
skip_signature: boolSkip signature will skip loading credentials and signing requests.