Struct OssConfig
#[non_exhaustive]pub struct OssConfig {Show 22 fields
pub root: Option<String>,
pub endpoint: Option<String>,
pub presign_endpoint: Option<String>,
pub bucket: String,
pub addressing_style: Option<String>,
pub presign_addressing_style: Option<String>,
pub enable_versioning: bool,
pub server_side_encryption: Option<String>,
pub server_side_encryption_key_id: Option<String>,
pub skip_signature: bool,
pub allow_anonymous: bool,
pub access_key_id: Option<String>,
pub access_key_secret: Option<String>,
pub security_token: Option<String>,
pub batch_max_operations: Option<usize>,
pub delete_max_size: Option<usize>,
pub role_arn: Option<String>,
pub role_session_name: Option<String>,
pub oidc_provider_arn: Option<String>,
pub oidc_token_file: Option<String>,
pub sts_endpoint: Option<String>,
pub external_id: Option<String>,
}services-oss only.Expand description
Config for Aliyun Object Storage Service (OSS) support.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.root: Option<String>Root for oss.
endpoint: Option<String>Endpoint for oss.
presign_endpoint: Option<String>Presign endpoint for oss.
bucket: StringBucket for oss.
addressing_style: Option<String>Addressing style for oss.
presign_addressing_style: Option<String>Pre sign addressing style for oss.
enable_versioning: boolDeprecated: OSS versioning capability is enabled by default.
server_side_encryption: Option<String>Server side encryption for oss.
server_side_encryption_key_id: Option<String>Server side encryption key id for oss.
skip_signature: boolSkip signature will skip loading credentials and signing requests.
allow_anonymous: boolskip_signature instead of allow_anonymousAllow anonymous for oss.
access_key_id: Option<String>Access key id for oss.
- this field if it’s
is_some - env value:
ALIBABA_CLOUD_ACCESS_KEY_ID
access_key_secret: Option<String>Access key secret for oss.
- this field if it’s
is_some - env value:
ALIBABA_CLOUD_ACCESS_KEY_SECRET
security_token: Option<String>security_token will be loaded from
- this field if it’s
is_some - env value:
ALIBABA_CLOUD_SECURITY_TOKEN
batch_max_operations: Option<usize>Deprecated: OSS delete batch capability is enabled by default.
delete_max_size: Option<usize>Deprecated: OSS delete batch capability is enabled by default.
role_arn: Option<String>If role_arn is set, we will use already known config as source
credential to assume role with role_arn.
- this field if it’s
is_some - env value:
ALIBABA_CLOUD_ROLE_ARN
role_session_name: Option<String>role_session_name for this backend.
oidc_provider_arn: Option<String>oidc_provider_arn will be loaded from
- this field if it’s
is_some - env value:
ALIBABA_CLOUD_OIDC_PROVIDER_ARN
oidc_token_file: Option<String>oidc_token_file will be loaded from
- this field if it’s
is_some - env value:
ALIBABA_CLOUD_OIDC_TOKEN_FILE
sts_endpoint: Option<String>sts_endpoint will be loaded from
- this field if it’s
is_some - env value:
ALIBABA_CLOUD_STS_ENDPOINT
external_id: Option<String>external_id for this backend.