pub struct Rocksdb { /* private fields */ }services-rocksdb only.Expand description
RocksDB service support.
Capabilities
Depending on its configuration and the backing system, this service can expose:
- create_dir
- stat
- read
- write
- delete
- list
- copy
- rename
-
presign
Inspect the effective capability set with opendal_core::Operator::info and
opendal_core::OperatorInfo::capability after building an operator.
Note
OpenDAL will build rocksdb from source by default.
To link with existing rocksdb lib, please set one of the following:
ROCKSDB_LIB_DIRto the dir that containslibrocksdb.soROCKSDB_STATICto the dir that containslibrocksdb.a
If the version of RocksDB is below 6.0, you may encounter compatibility
issues. It is advisable to follow the steps provided in the INSTALL
file to build rocksdb, rather than relying on system libraries that
may be outdated and incompatible.
Configuration
Use crate::RocksdbConfig for serializable configuration and this builder’s
methods for direct construction. The field and method documentation defines
accepted values, defaults, and environment interaction.
Example
Via Builder
use opendal_core::Operator;
use opendal_core::Result;
use opendal_service_rocksdb::Rocksdb;
#[tokio::main]
async fn main() -> Result<()> {
let mut builder = Rocksdb::default()
.datadir("/tmp/opendal/rocksdb");
let op: Operator = Operator::new(builder)?;
Ok(())
}Implementations
Sourceimpl RocksdbBuilder
impl RocksdbBuilder
Sourcepub fn datadir(self, path: &str) -> RocksdbBuilder
pub fn datadir(self, path: &str) -> RocksdbBuilder
Set the path to the rocksdb data directory. Creates if not exists.
Sourcepub fn root(self, root: &str) -> RocksdbBuilder
pub fn root(self, root: &str) -> RocksdbBuilder
Set the working directory, all operations will be performed under it.
default: “/”