pub struct Surrealdb { /* private fields */ }services-surrealdb only.Expand description
Capabilities
Depending on its configuration and the backing system, this service can expose:
- create_dir
- stat
- read
- write
- delete
- list
- copy
- rename
-
presign
Inspect the effective capability set with opendal_core::Operator::info and
opendal_core::OperatorInfo::capability after building an operator.
Configuration
Use crate::SurrealdbConfig for serializable configuration and this builder’s
methods for direct construction. The field and method documentation defines
accepted values, defaults, and environment interaction.
Example
Via Builder
use opendal_core::Operator;
use opendal_core::Result;
use opendal_service_surrealdb::Surrealdb;
#[tokio::main]
async fn main() -> Result<()> {
let mut builder = Surrealdb::default()
.root("/")
.connection_string("ws://127.0.0.1:8000")
.username("username")
.password("password")
.namespace("namespace")
.database("database")
.table("table")
.key_field("key")
.value_field("value");
let op = Operator::new(builder)?;
Ok(())
}Implementations
Sourceimpl SurrealdbBuilder
impl SurrealdbBuilder
Sourcepub fn connection_string(self, connection_string: &str) -> SurrealdbBuilder
pub fn connection_string(self, connection_string: &str) -> SurrealdbBuilder
Set the connection_string of the surrealdb service.
This connection string is used to connect to the surrealdb service. There are url based formats:
Url
ws://ip:portwss://ip:porthttp://ip:porthttps://ip:port
Sourcepub fn root(self, root: &str) -> SurrealdbBuilder
pub fn root(self, root: &str) -> SurrealdbBuilder
set the working directory, all operations will be performed under it.
default: “/”
Sourcepub fn table(self, table: &str) -> SurrealdbBuilder
pub fn table(self, table: &str) -> SurrealdbBuilder
Set the table name of the surrealdb service for read/write.
Sourcepub fn username(self, username: &str) -> SurrealdbBuilder
pub fn username(self, username: &str) -> SurrealdbBuilder
Set the username of the surrealdb service for signin.
Sourcepub fn password(self, password: &str) -> SurrealdbBuilder
pub fn password(self, password: &str) -> SurrealdbBuilder
Set the password of the surrealdb service for signin.
Sourcepub fn namespace(self, namespace: &str) -> SurrealdbBuilder
pub fn namespace(self, namespace: &str) -> SurrealdbBuilder
Set the namespace of the surrealdb service for read/write.
Sourcepub fn database(self, database: &str) -> SurrealdbBuilder
pub fn database(self, database: &str) -> SurrealdbBuilder
Set the database of the surrealdb service for read/write.
Sourcepub fn key_field(self, key_field: &str) -> SurrealdbBuilder
pub fn key_field(self, key_field: &str) -> SurrealdbBuilder
Set the key field name of the surrealdb service for read/write.
Default to key if not specified.
Sourcepub fn value_field(self, value_field: &str) -> SurrealdbBuilder
pub fn value_field(self, value_field: &str) -> SurrealdbBuilder
Set the value field name of the surrealdb service for read/write.
Default to value if not specified.