Struct Tos
pub struct Tos { /* private fields */ }Available on crate feature
services-tos only.Expand description
Builder for Volcengine TOS service.
Capabilities
This service can be used to:
- create_dir
- stat
- read
- write
- delete
- list
- copy
- rename
- presign
Configuration
root: Set the work directory for backend.bucket: Set the bucket name for backend.endpoint: Set the endpoint for backend.region: Set the region for backend.access_key_id: Set the access_key_id for backend.secret_access_key: Set the secret_access_key for backend.security_token: Set the security token for backend.
Refer to TosBuilder’s public API docs for more information.
Example
Via Builder
use opendal_core::Operator;
use opendal_core::Result;
use opendal_service_tos::Tos;
fn main() -> Result<()> {
let builder = Tos::default()
// Set the root for TOS, all operations will happen under this root.
.root("/path/to/dir")
// Set the bucket name. This is required.
.bucket("test")
// Set the endpoint.
//
// For example:
// - "https://tos-cn-beijing.volces.com"
// - "https://tos-cn-shanghai.volces.com"
.endpoint("https://tos-cn-beijing.volces.com")
// Set the region.
.region("cn-beijing")
// Set the access_key_id and secret_access_key.
//
// OpenDAL will try to load credentials from the environment if
// credentials are not set explicitly.
.access_key_id("access_key_id")
.secret_access_key("secret_access_key");
let _op: Operator = Operator::new(builder)?.finish();
Ok(())
}Implementations
impl TosBuilder
impl TosBuilder
pub fn root(self, root: &str) -> TosBuilder
pub fn root(self, root: &str) -> TosBuilder
Set root of this backend.
All operations will happen under this root.
pub fn bucket(self, bucket: &str) -> TosBuilder
pub fn bucket(self, bucket: &str) -> TosBuilder
Set bucket name of this backend.
pub fn endpoint(self, endpoint: &str) -> TosBuilder
pub fn endpoint(self, endpoint: &str) -> TosBuilder
Set endpoint of this backend.
Endpoint must be full uri, e.g.
- TOS:
https://tos-cn-beijing.volces.com - TOS with region:
https://tos-{region}.volces.com
If user inputs endpoint without scheme like “tos-cn-beijing.volces.com”, we will prepend “https://” before it.
pub fn region(self, region: &str) -> TosBuilder
pub fn region(self, region: &str) -> TosBuilder
Set region of this backend.
Region represent the signing region of this endpoint.
If region is not set, we will try to load it from environment.
If still not set, default to cn-beijing.
pub fn access_key_id(self, v: &str) -> TosBuilder
pub fn access_key_id(self, v: &str) -> TosBuilder
Set access_key_id of this backend.
- If access_key_id is set, we will take user’s input first.
- If not, we will try to load it from environment.
pub fn secret_access_key(self, v: &str) -> TosBuilder
pub fn secret_access_key(self, v: &str) -> TosBuilder
Set secret_access_key of this backend.
- If secret_access_key is set, we will take user’s input first.
- If not, we will try to load it from environment.
pub fn security_token(self, v: &str) -> TosBuilder
pub fn security_token(self, v: &str) -> TosBuilder
Set security_token of this backend.
pub fn skip_signature(self) -> TosBuilder
pub fn skip_signature(self) -> TosBuilder
Skip signature will skip loading credentials and signing requests.