Struct TosConfig
#[non_exhaustive]pub struct TosConfig {
pub root: Option<String>,
pub bucket: String,
pub endpoint: Option<String>,
pub region: Option<String>,
pub access_key_id: Option<String>,
pub secret_access_key: Option<String>,
pub security_token: Option<String>,
pub disable_config_load: bool,
pub skip_signature: bool,
}Available on crate feature
services-tos only.Expand description
Config for Volcengine TOS service.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.root: Option<String>root of this backend.
All operations will happen under this root.
default to / if not set.
bucket: Stringbucket name of this backend.
required.
endpoint: Option<String>endpoint of this backend.
Endpoint must be full uri, e.g.
- TOS:
https://tos-cn-beijing.volces.com - TOS with region:
https://tos-{region}.volces.com
If user inputs endpoint without scheme like “tos-cn-beijing.volces.com”, we will prepend “https://” before it.
region: Option<String>Region represent the signing region of this endpoint.
Required if endpoint is not provided.
- If region is set, we will take user’s input first.
- If not, we will try to load it from environment.
- If still not set, default to
cn-beijing.
access_key_id: Option<String>access_key_id of this backend.
- If access_key_id is set, we will take user’s input first.
- If not, we will try to load it from environment.
secret_access_key: Option<String>secret_access_key of this backend.
- If secret_access_key is set, we will take user’s input first.
- If not, we will try to load it from environment.
security_token: Option<String>security_token of this backend.
This token will expire after sometime, it’s recommended to set security_token by hand.
disable_config_load: boolDisable config load so that opendal will not load config from environment.
For examples:
- envs like
TOS_ACCESS_KEY_ID
skip_signature: boolSkip signature will skip loading credentials and signing requests.