IntoDeleteInput

Trait IntoDeleteInput 

pub trait IntoDeleteInput:
    Send
    + Sync
    + Unpin {
    // Required method
    fn into_delete_input(self) -> (String, DeleteOptions);
}
Converts a value into an owned path and logical delete options.

Deleter lowers the returned options against the composed service capability immediately before passing raw arguments to the service.

Required Methods

fn into_delete_input(self) -> (String, DeleteOptions)

Convert self into an owned path and delete options.

Implementations on Foreign Types



impl IntoDeleteInput for &str

Implement IntoDeleteInput for &str so path streams can borrow their items.



impl IntoDeleteInput for (String, DeleteOptions)

Implement IntoDeleteInput for an owned path with logical delete options.



impl IntoDeleteInput for String

Implement IntoDeleteInput for String so Vec<String> can be deleted directly.

Implementors



impl IntoDeleteInput for Entry

Implement IntoDeleteInput for Entry so a lister can feed a deleter.