pub fn install_default()Expand description
Install the global defaults provided by the facade crate.
This function is safe to call multiple times. It registers enabled services and installs the default HTTP transport when the corresponding feature is enabled.