Service builders enabled through services-* Cargo features.
Memory is always available. Other builders are
re-exported when their matching facade feature is enabled; for example,
services-s3 enables S3.
Pass a configured builder to Operator::new. The facade automatically
registers enabled services for Operator::from_uri and
Operator::via_iter when the auto-register-services feature is enabled.
Structs
- Aliyun
Drive services-aliyun-drive - Capabilities
- Aliyun
Drive Config services-aliyun-drive - Config for Aliyun Drive services support.
- Alluxio
services-alluxio - Alluxio services support.
- Alluxio
Config services-alluxio - Config for alluxio services support.
- Azblob
services-azblob - Capabilities
- Azblob
Config services-azblob - Azure Storage Blob services support.
- Azdls
services-azdls - Azure Data Lake Storage Gen2 Support.
As known as
abfs,azdlsorazdls. - Azdls
Config services-azdls - Azure Data Lake Storage Gen2 Support.
- Azfile
services-azfile - Azure File services support.
- Azfile
Config services-azfile - Azure File services support.
- B2
services-b2 - b2 services support.
- B2Config
services-b2 - Config for backblaze b2 services support.
- Cacache
services-cacache - cacache service support.
- Cacache
Config services-cacache - cacache service support.
- Cloudflare
Kv services-cloudflare-kv - Capabilities
- Cloudflare
KvConfig services-cloudflare-kv - Cloudflare KV Service Support.
- Compfs
services-compfs compio-based file system support.- Compfs
Config services-compfs - compio-based file system support.
- Cos
services-cos - Tencent-Cloud COS services support.
- CosConfig
services-cos - Tencent-Cloud COS services support.
- D1
services-d1 - Capabilities
- D1Config
services-d1 - Config for Cloudflare D1 backend support.
- Dashmap
services-dashmap - dashmap backend support.
- Dashmap
Config services-dashmap - Config for Dashmap services support.
- Dbfs
services-dbfs - Dbfs’s REST API support. This service will visit the DBFS API supported by Databricks File System.
- Dbfs
Config services-dbfs - Dbfs’s REST API support.
- Dropbox
services-dropbox - Dropbox backend support.
- Dropbox
Config services-dropbox - Config for Dropbox backend support.
- Etcd
services-etcd - Etcd services support.
- Etcd
Config services-etcd - Config for Etcd services support.
- Foundationdb
services-foundationdb - Capabilities
- Foundationdb
Config services-foundationdb - foundationdb service support. Config for FoundationDB.
- Foyer
services-foyer - foyer backend support.
- Foyer
Config services-foyer - Config for Foyer services support.
- Foyer
Key services-foyer FoyerKeyis a key for the foyer cache.- Foyer
Value services-foyer FoyerValueis a wrapper aroundBufferthat implements theCodetrait.- Fs
services-fs - POSIX file system support.
- FsConfig
services-fs - config for file system
- Ftp
services-ftp - FTP and FTPS services support.
- FtpConfig
services-ftp - Config for Ftp services support.
- Gcs
services-gcs - Google Cloud Storage services support.
- GcsConfig
services-gcs - Google Cloud Storage services support.
- Gdrive
services-gdrive - GoogleDrive backend support.
- Gdrive
Config services-gdrive - GoogleDrive configuration.
- Ghac
services-ghac - GitHub Action Cache Services support.
- Ghac
Config services-ghac - Config for GitHub Action Cache Services support.
- Github
services-github - github contents services support.
- Github
Config services-github - Config for GitHub services support.
- GooseFs
services-goosefs - GooseFS services support via native gRPC.
- Goosefs
Config services-goosefs - Config for GooseFS service support.
- Gridfs
services-gridfs - Capabilities
- Gridfs
Config services-gridfs - Config for Grid file system support.
- Hdfs
services-hdfs - A distributed file system that provides high-throughput access to application data.
- Hdfs
Config services-hdfs - Hadoop Distributed File System (HDFS™) support.
- Hdfs
Native services-hdfs-native - Hadoop Distributed File System (HDFS™) support. Using Native Rust HDFS client. A distributed file system that provides high-throughput access to application data. Using Native Rust HDFS client.
- Hdfs
Native Config services-hdfs-native - Config for HdfsNative services support.
- Hf
services-hf - Hugging Face’s API support. This service will visit the Hugging Face API to access the Hugging Face File System.
- HfConfig
services-hf - Configuration for Hugging Face service support.
- Http
services-http - HTTP Read-only service support like Nginx and Caddy.
- Http
Config services-http - Config for Http service support.
- Ipfs
services-ipfs - IPFS file system support based on IPFS HTTP Gateway.
- Ipfs
Config services-ipfs - Config for IPFS file system support.
- Ipmfs
services-ipmfs - IPFS file system support based on IPFS MFS API.
- Ipmfs
Config services-ipmfs - Config for IPFS MFS support.
- Koofr
services-koofr - Koofr services support.
- Koofr
Config services-koofr - Config for Koofr services support.
- Lakefs
services-lakefs - Lakefs’s API support.
This service will visit the Lakefs API to access the Lakefs File System.
Currently, we only support the
modelanddatasettypes of repositories, and operations are limited to reading and listing/stating. - Lakefs
Config services-lakefs - Configuration for Lakefs service support.
- Memcached
services-memcached - Memcached service support.
- Memcached
Config services-memcached - Config for MemCached services support
- Memory
- In memory service support. (BTreeMap Based)
- Memory
Config - Config for memory.
- Mini
Moka services-mini-moka - mini-moka backend support.
- Mini
Moka Config services-mini-moka - Config for mini-moka support.
- Moka
services-moka - moka backend support.
- Moka
Config services-moka - Config for Moka services support.
- Moka
Value services-moka - Value stored in moka cache containing both metadata and content
- Mongodb
services-mongodb - Capabilities
- Mongodb
Config services-mongodb - Config for Mongodb service support.
- Monoiofs
services-monoiofs - File system support via
monoio. - Monoiofs
Config services-monoiofs - Config for monoiofs services support.
- Mysql
services-mysql - Capabilities
- Mysql
Config services-mysql - Config for Mysql services support.
- Obs
services-obs - Huawei-Cloud Object Storage Service (OBS) support
- ObsConfig
services-obs - Config for Huawei-Cloud Object Storage Service (OBS) support.
- Onedrive
services-onedrive - Microsoft OneDrive backend support.
- Onedrive
Config services-onedrive - Config for OneDrive backend support.
- Oss
services-oss - Aliyun Object Storage Service (OSS) support
- OssConfig
services-oss - Config for Aliyun Object Storage Service (OSS) support.
- Pcloud
services-pcloud - pCloud services support.
- Pcloud
Config services-pcloud - Config for Pcloud services support.
- Persy
services-persy - persy service support.
- Persy
Config services-persy - Config for persy service support.
- Postgresql
services-postgresql - PostgreSQL services support.
- Postgresql
Config services-postgresql - Config for PostgreSQL services support.
- Redb
services-redb - Redb service support.
- Redb
Config services-redb - Config for redb service support.
- Redis
services-redis - Redis services support.
- Redis
Config services-redis - Config for Redis services support.
- Rocksdb
services-rocksdb - RocksDB service support.
- Rocksdb
Config services-rocksdb - Config for Rocksdb Service.
- S3
services-s3 - Aws S3 and compatible services (including minio, digitalocean space, Tencent Cloud Object Storage(COS) and so on) support. For more information about s3-compatible services, refer to Compatible Services.
- S3Config
services-s3 - Config for Aws S3 and compatible services (including minio, digitalocean space, Tencent Cloud Object Storage(COS) and so on) support.
- Seafile
services-seafile - seafile services support.
- Seafile
Config services-seafile - Config for seafile services support.
- Sftp
services-sftp - SFTP services support. (only works on unix)
- Sftp
Config services-sftp - Config for Sftp Service support.
- Sled
services-sled - Sled services support.
- Sled
Config services-sled - Config for Sled services support.
- Sqlite
services-sqlite - Capabilities
- Sqlite
Config services-sqlite - Config for Sqlite support.
- Surrealdb
services-surrealdb - Capabilities
- Surrealdb
Config services-surrealdb - Config for Surrealdb services support.
- Swift
services-swift - OpenStack Swift’s REST API support. For more information about swift-compatible services, refer to Compatible Services.
- Swift
Config services-swift - Config for OpenStack Swift support.
- Tikv
services-tikv - TiKV backend builder
- Tikv
Config services-tikv - Config for Tikv services support.
- Tos
services-tos - Builder for Volcengine TOS service.
- TosConfig
services-tos - Config for Volcengine TOS service.
- Upyun
services-upyun - upyun services support.
- Upyun
Config services-upyun - Config for upyun services support.
- Vercel
Artifacts services-vercel-artifacts - Vercel Cache backend support.
- Vercel
Artifacts Config services-vercel-artifacts - Config for Vercel Cache support.
- Vercel
Blob services-vercel-blob - VercelBlob services support.
- Vercel
Blob Config services-vercel-blob - Config for VercelBlob services support.
- Webdav
services-webdav - WebDAV backend support.
- Webdav
Config services-webdav - Config for WebDAV backend support.
- Webhdfs
services-webhdfs - WebHDFS’s REST API support. There two implementations of WebHDFS REST API:
- Webhdfs
Config services-webhdfs - Config for WebHDFS support.
- Yandex
Disk services-yandex-disk - YandexDisk services support.
- Yandex
Disk Config services-yandex-disk - Config for YandexDisk services support.
Constants
- ALIYUN_
DRIVE_ SCHEME services-aliyun-drive - URI scheme used for service registration and scheme-driven construction.
- ALLUXIO_
SCHEME services-alluxio - URI scheme used for service registration and scheme-driven construction.
- AZBLOB_
SCHEME services-azblob - URI scheme used for service registration and scheme-driven construction.
- AZDLS_
SCHEME services-azdls - URI scheme used for service registration and scheme-driven construction.
- AZFILE_
SCHEME services-azfile - URI scheme used for service registration and scheme-driven construction.
- B2_
SCHEME services-b2 - URI scheme used for service registration and scheme-driven construction.
- CACACHE_
SCHEME services-cacache - URI scheme used for service registration and scheme-driven construction.
- CLOUDFLARE_
KV_ SCHEME services-cloudflare-kv - URI scheme used for service registration and scheme-driven construction.
- COMPFS_
SCHEME services-compfs - URI scheme used for service registration and scheme-driven construction.
- COSN_
SCHEME services-cos - Alternative scheme for cos service.
- COS_
SCHEME services-cos - URI scheme used for service registration and scheme-driven construction.
- D1_
SCHEME services-d1 - URI scheme used for service registration and scheme-driven construction.
- DASHMAP_
SCHEME services-dashmap - URI scheme used for service registration and scheme-driven construction.
- DBFS_
SCHEME services-dbfs - URI scheme used for service registration and scheme-driven construction.
- DROPBOX_
SCHEME services-dropbox - URI scheme used for service registration and scheme-driven construction.
- ETCD_
SCHEME services-etcd - URI scheme used for service registration and scheme-driven construction.
- FILE_
SCHEME services-fs - Alias scheme for fs service that follows the standard URI scheme.
- FOUNDATIONDB_
SCHEME services-foundationdb - URI scheme used for service registration and scheme-driven construction.
- FOYER_
SCHEME services-foyer - URI scheme used for service registration and scheme-driven construction.
- FS_
SCHEME services-fs - URI scheme used for service registration and scheme-driven construction.
- FTP_
SCHEME services-ftp - URI scheme used for service registration and scheme-driven construction.
- GCS_
SCHEME services-gcs - URI scheme used for service registration and scheme-driven construction.
- GDRIVE_
SCHEME services-gdrive - URI scheme used for service registration and scheme-driven construction.
- GHAC_
SCHEME services-ghac - URI scheme used for service registration and scheme-driven construction.
- GITHUB_
SCHEME services-github - URI scheme used for service registration and scheme-driven construction.
- GOOSEFS_
SCHEME services-goosefs - URI scheme used for service registration and scheme-driven construction.
- GRIDFS_
SCHEME services-gridfs - URI scheme used for service registration and scheme-driven construction.
- HDFS_
NATIVE_ SCHEME services-hdfs-native - URI scheme used for service registration and scheme-driven construction.
- HDFS_
SCHEME services-hdfs - URI scheme used for service registration and scheme-driven construction.
- HF_
SCHEME services-hf - Primary URI scheme registered for the Hugging Face service.
- HTTPS_
SCHEME services-http - Alias URI scheme used for HTTPS connections.
- HTTP_
SCHEME services-http - URI scheme used for service registration and scheme-driven construction.
- HUGGINGFACE_
SCHEME services-hf - Alias URI scheme registered for the Hugging Face service.
- IPFS_
SCHEME services-ipfs - URI scheme used for service registration and scheme-driven construction.
- IPMFS_
SCHEME services-ipmfs - URI scheme used for service registration and scheme-driven construction.
- KOOFR_
SCHEME services-koofr - URI scheme used for service registration and scheme-driven construction.
- LAKEFS_
SCHEME services-lakefs - URI scheme used for service registration and scheme-driven construction.
- MEMCACHED_
SCHEME services-memcached - URI scheme used for service registration and scheme-driven construction.
- MEMORY_
SCHEME - URI scheme used for memory service registration and URI construction.
- MINI_
MOKA_ SCHEME services-mini-moka - URI scheme used for service registration and scheme-driven construction.
- MOKA_
SCHEME services-moka - URI scheme used for service registration and scheme-driven construction.
- MONGODB_
SCHEME services-mongodb - URI scheme used for service registration and scheme-driven construction.
- MONOIOFS_
SCHEME services-monoiofs - URI scheme used for service registration and scheme-driven construction.
- MYSQL_
SCHEME services-mysql - URI scheme used for service registration and scheme-driven construction.
- OBS_
SCHEME services-obs - URI scheme used for service registration and scheme-driven construction.
- ONEDRIVE_
SCHEME services-onedrive - URI scheme used for service registration and scheme-driven construction.
- OSS_
SCHEME services-oss - URI scheme used for service registration and scheme-driven construction.
- PCLOUD_
SCHEME services-pcloud - URI scheme used for service registration and scheme-driven construction.
- PERSY_
SCHEME services-persy - URI scheme used for service registration and scheme-driven construction.
- POSTGRESQL_
SCHEME services-postgresql - URI scheme used for service registration and scheme-driven construction.
- REDB_
SCHEME services-redb - URI scheme used for service registration and scheme-driven construction.
- REDIS_
SCHEME services-redis - URI scheme used for service registration and scheme-driven construction.
- ROCKSDB_
SCHEME services-rocksdb - URI scheme used for service registration and scheme-driven construction.
- S3_
SCHEME services-s3 - URI scheme used for service registration and scheme-driven construction.
- SEAFILE_
SCHEME services-seafile - URI scheme used for service registration and scheme-driven construction.
- SFTP_
SCHEME services-sftp - URI scheme used for service registration and scheme-driven construction.
- SLED_
SCHEME services-sled - URI scheme used for service registration and scheme-driven construction.
- SQLITE_
SCHEME services-sqlite - URI scheme used for service registration and scheme-driven construction.
- SURREALDB_
SCHEME services-surrealdb - URI scheme used for service registration and scheme-driven construction.
- SWIFT_
SCHEME services-swift - URI scheme used for service registration and scheme-driven construction.
- TIKV_
SCHEME services-tikv - URI scheme used for service registration and scheme-driven construction.
- TOS_
SCHEME services-tos - URI scheme used for service registration and scheme-driven construction.
- UPYUN_
SCHEME services-upyun - URI scheme used for service registration and scheme-driven construction.
- VERCEL_
ARTIFACTS_ SCHEME services-vercel-artifacts - URI scheme used for service registration and scheme-driven construction.
- VERCEL_
BLOB_ SCHEME services-vercel-blob - URI scheme used for service registration and scheme-driven construction.
- WEBDAV_
SCHEME services-webdav - URI scheme used for service registration and scheme-driven construction.
- WEBHDFS_
SCHEME services-webhdfs - URI scheme used for service registration and scheme-driven construction.
- YANDEX_
DISK_ SCHEME services-yandex-disk - URI scheme used for service registration and scheme-driven construction.
Functions
- register_
aliyun_ drive_ service services-aliyun-drive - Register this service’s URI scheme or schemes with an operator registry.
- register_
alluxio_ service services-alluxio - Register this service’s URI scheme or schemes with an operator registry.
- register_
azblob_ service services-azblob - Register this service’s URI scheme or schemes with an operator registry.
- register_
azdls_ service services-azdls - Register this service’s URI scheme or schemes with an operator registry.
- register_
azfile_ service services-azfile - Register this service’s URI scheme or schemes with an operator registry.
- register_
b2_ service services-b2 - Register this service’s URI scheme or schemes with an operator registry.
- register_
cacache_ service services-cacache - Register this service’s URI scheme or schemes with an operator registry.
- register_
cloudflare_ kv_ service services-cloudflare-kv - Register this service’s URI scheme or schemes with an operator registry.
- register_
compfs_ service services-compfs - Register this service’s URI scheme or schemes with an operator registry.
- register_
cos_ service services-cos - Register this service’s URI scheme or schemes with an operator registry.
- register_
d1_ service services-d1 - Register this service’s URI scheme or schemes with an operator registry.
- register_
dashmap_ service services-dashmap - Register this service’s URI scheme or schemes with an operator registry.
- register_
dbfs_ service services-dbfs - Register this service’s URI scheme or schemes with an operator registry.
- register_
dropbox_ service services-dropbox - Register this service’s URI scheme or schemes with an operator registry.
- register_
etcd_ service services-etcd - Register this service’s URI scheme or schemes with an operator registry.
- register_
foundationdb_ service services-foundationdb - Register this service’s URI scheme or schemes with an operator registry.
- register_
foyer_ service services-foyer - Register this service’s URI scheme or schemes with an operator registry.
- register_
fs_ service services-fs - Register this service’s URI scheme or schemes with an operator registry.
- register_
ftp_ service services-ftp - Register this service’s URI scheme or schemes with an operator registry.
- register_
gcs_ service services-gcs - Register this service’s URI scheme or schemes with an operator registry.
- register_
gdrive_ service services-gdrive - Register this service’s URI scheme or schemes with an operator registry.
- register_
ghac_ service services-ghac - Register this service’s URI scheme or schemes with an operator registry.
- register_
github_ service services-github - Register this service’s URI scheme or schemes with an operator registry.
- register_
goosefs_ service services-goosefs - Register this service’s URI scheme or schemes with an operator registry.
- register_
gridfs_ service services-gridfs - Register this service’s URI scheme or schemes with an operator registry.
- register_
hdfs_ native_ service services-hdfs-native - Register this service’s URI scheme or schemes with an operator registry.
- register_
hdfs_ service services-hdfs - Register this service’s URI scheme or schemes with an operator registry.
- register_
hf_ service services-hf - Register this service’s URI scheme or schemes with an operator registry.
- register_
http_ service services-http - Register this service’s URI scheme or schemes with an operator registry.
- register_
ipfs_ service services-ipfs - Register this service’s URI scheme or schemes with an operator registry.
- register_
ipmfs_ service services-ipmfs - Register this service’s URI scheme or schemes with an operator registry.
- register_
koofr_ service services-koofr - Register this service’s URI scheme or schemes with an operator registry.
- register_
lakefs_ service services-lakefs - Register this service’s URI scheme or schemes with an operator registry.
- register_
memcached_ service services-memcached - Register this service’s URI scheme or schemes with an operator registry.
- register_
memory_ service - Register the memory URI scheme with an operator registry.
- register_
mini_ moka_ service services-mini-moka - Register this service’s URI scheme or schemes with an operator registry.
- register_
moka_ service services-moka - Register this service’s URI scheme or schemes with an operator registry.
- register_
mongodb_ service services-mongodb - Register this service’s URI scheme or schemes with an operator registry.
- register_
monoiofs_ service services-monoiofs - Register this service’s URI scheme or schemes with an operator registry.
- register_
mysql_ service services-mysql - Register this service’s URI scheme or schemes with an operator registry.
- register_
obs_ service services-obs - Register this service’s URI scheme or schemes with an operator registry.
- register_
onedrive_ service services-onedrive - Register this service’s URI scheme or schemes with an operator registry.
- register_
oss_ service services-oss - Register this service’s URI scheme or schemes with an operator registry.
- register_
pcloud_ service services-pcloud - Register this service’s URI scheme or schemes with an operator registry.
- register_
persy_ service services-persy - Register this service’s URI scheme or schemes with an operator registry.
- register_
postgresql_ service services-postgresql - Register this service’s URI scheme or schemes with an operator registry.
- register_
redb_ service services-redb - Register this service’s URI scheme or schemes with an operator registry.
- register_
redis_ service services-redis - Register this service’s URI scheme or schemes with an operator registry.
- register_
rocksdb_ service services-rocksdb - Register this service’s URI scheme or schemes with an operator registry.
- register_
s3_ service services-s3 - Register this service’s URI scheme or schemes with an operator registry.
- register_
seafile_ service services-seafile - Register this service’s URI scheme or schemes with an operator registry.
- register_
sftp_ service services-sftp - Register this service’s URI scheme or schemes with an operator registry.
- register_
sled_ service services-sled - Register this service’s URI scheme or schemes with an operator registry.
- register_
sqlite_ service services-sqlite - Register this service’s URI scheme or schemes with an operator registry.
- register_
surrealdb_ service services-surrealdb - Register this service’s URI scheme or schemes with an operator registry.
- register_
swift_ service services-swift - Register this service’s URI scheme or schemes with an operator registry.
- register_
tikv_ service services-tikv - Register this service’s URI scheme or schemes with an operator registry.
- register_
tos_ service services-tos - Register this service’s URI scheme or schemes with an operator registry.
- register_
upyun_ service services-upyun - Register this service’s URI scheme or schemes with an operator registry.
- register_
vercel_ artifacts_ service services-vercel-artifacts - Register this service’s URI scheme or schemes with an operator registry.
- register_
vercel_ blob_ service services-vercel-blob - Register this service’s URI scheme or schemes with an operator registry.
- register_
webdav_ service services-webdav - Register this service’s URI scheme or schemes with an operator registry.
- register_
webhdfs_ service services-webhdfs - Register this service’s URI scheme or schemes with an operator registry.
- register_
yandex_ disk_ service services-yandex-disk - Register this service’s URI scheme or schemes with an operator registry.
Type Aliases
- Moka
Cache Builder services-moka - Type alias of
moka::future::CacheBuilder