Struct Hf
pub struct Hf { /* private fields */ }services-hf only.Expand description
Hugging Face’s API support.
This service will visit the Hugging Face API to access the Hugging Face File System.
Currently, we only support the model and dataset types of repositories, and operations are limited to reading and listing/stating.
Hugging Face doesn’t host official HTTP API docs. Detailed HTTP request API information can be found on the huggingface_hub Source Code.
Both hf:// and huggingface:// URI schemes are supported.
Capabilities
This service can be used to:
- create_dir
- stat
- read
- write
- delete
- list
- copy
- rename
-
presign
Configurations
repo_type: The type of the repository.repo_id: The id of the repository.revision: The revision of the repository.root: Set the work directory for backend.token: The token for accessing the repository.
Refer to HfBuilder’s public API docs for more information.
Examples
Via Builder
use opendal_core::Operator;
use opendal_core::Result;
use opendal_service_hf::Hf;
#[tokio::main]
async fn main() -> Result<()> {
// Create Hugging Face backend builder
let mut builder = Hf::default()
// set the type of Hugging Face repository
.repo_type("dataset")
// set the id of Hugging Face repository
.repo_id("databricks/databricks-dolly-15k")
// set the revision of Hugging Face repository
.revision("main")
// set the root, all operations will happen under this root
.root("/path/to/dir")
// set the token for accessing the repository
.token("access_token");
let op: Operator = Operator::new(builder)?.finish();
Ok(())
}Implementations
impl HfBuilder
impl HfBuilder
pub fn repo_type(self, repo_type: &str) -> HfBuilder
pub fn repo_type(self, repo_type: &str) -> HfBuilder
Set repo type of this backend. Default is model.
Available values:
- model
- dataset
- datasets (alias for dataset)
- space
pub fn repo_id(self, repo_id: &str) -> HfBuilder
pub fn repo_id(self, repo_id: &str) -> HfBuilder
Set repo id of this backend. This is required.
Repo id consists of the account name and the repository name.
For example, model’s repo id looks like:
- meta-llama/Llama-2-7b
Dataset’s repo id looks like:
- databricks/databricks-dolly-15k
pub fn revision(self, revision: &str) -> HfBuilder
pub fn revision(self, revision: &str) -> HfBuilder
Set revision of this backend. Default is main.
Revision can be a branch name or a commit hash.
For example, revision can be:
- main
- 1d0c4eb