Struct Tos
pub struct Tos { /* private fields */ }services-tos only.Expand description
Builder for Volcengine TOS service.
Implementations
impl TosBuilder
impl TosBuilder
pub fn root(self, root: &str) -> TosBuilder
pub fn root(self, root: &str) -> TosBuilder
Set root of this backend.
All operations will happen under this root.
pub fn bucket(self, bucket: &str) -> TosBuilder
pub fn bucket(self, bucket: &str) -> TosBuilder
Set bucket name of this backend.
pub fn endpoint(self, endpoint: &str) -> TosBuilder
pub fn endpoint(self, endpoint: &str) -> TosBuilder
Set endpoint of this backend.
Endpoint must be full uri, e.g.
- TOS:
https://tos-cn-beijing.volces.com - TOS with region:
https://tos-{region}.volces.com
If user inputs endpoint without scheme like “tos-cn-beijing.volces.com”, we will prepend “https://” before it.
pub fn region(self, region: &str) -> TosBuilder
pub fn region(self, region: &str) -> TosBuilder
Set region of this backend.
Region represent the signing region of this endpoint.
If region is not set, we will try to load it from environment.
If still not set, default to cn-beijing.
pub fn access_key_id(self, v: &str) -> TosBuilder
pub fn access_key_id(self, v: &str) -> TosBuilder
Set access_key_id of this backend.
- If access_key_id is set, we will take user’s input first.
- If not, we will try to load it from environment.
pub fn secret_access_key(self, v: &str) -> TosBuilder
pub fn secret_access_key(self, v: &str) -> TosBuilder
Set secret_access_key of this backend.
- If secret_access_key is set, we will take user’s input first.
- If not, we will try to load it from environment.
pub fn security_token(self, v: &str) -> TosBuilder
pub fn security_token(self, v: &str) -> TosBuilder
Set security_token of this backend.
pub fn allow_anonymous(self, allow: bool) -> TosBuilder
pub fn allow_anonymous(self, allow: bool) -> TosBuilder
Allow anonymous will allow opendal to send request without signing when credential is not loaded.
pub fn enable_versioning(self, enabled: bool) -> TosBuilder
pub fn enable_versioning(self, enabled: bool) -> TosBuilder
Set bucket versioning status for this backend.
If set to true, OpenDAL will support versioned operations like list with versions, read with version, etc.