Struct FuturesAsyncReader
pub struct FuturesAsyncReader { /* private fields */ }Expand description
FuturesAsyncReader is the adapter of [AsyncRead], [AsyncBufRead]
and [AsyncSeek] generated by Reader::into_futures_async_read.
Users can use this adapter in cases where they need to use [AsyncRead]
related trait. FuturesAsyncReader reuses the same concurrent and chunk
settings from Reader.
An unbounded read treats ErrorKind::RangeNotSatisfied as EOF. Bounded
reads and other errors are propagated.
Implementations
impl FuturesAsyncReader
impl FuturesAsyncReader
pub async fn read_buffer(&mut self, size: usize) -> Result<Buffer, Error>
pub async fn read_buffer(&mut self, size: usize) -> Result<Buffer, Error>
Read at most size bytes and return them as an OpenDAL Buffer.
This method preserves the underlying buffer storage and does not copy the payload. It can return fewer bytes than requested, including an empty buffer at EOF.
pub async fn read_to_end_buffer(&mut self) -> Result<Buffer, Error>
pub async fn read_to_end_buffer(&mut self) -> Result<Buffer, Error>
Read all remaining bytes and return them as an OpenDAL Buffer.
This method preserves the underlying buffer storage and only allocates metadata when multiple buffers must be combined.